@@ -1,12 +1,12 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-07-15'; # DATE
-our $VERSION = '1.54'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '1.55'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
 #use warnings; # enabled by Moo
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Moo;
 use experimental 'smartmatch'; # must be after Moo
@@ -778,7 +778,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.54 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-07-15.
+This document describes version 1.55 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
